@@ -6,8 +6,7 @@
 all() -> [sub_app_deps, newly_added_dep, newly_added_after_empty_lock, no_deps_empty_lock,
           http_proxy_settings, https_proxy_settings,
           http_os_proxy_settings, https_os_proxy_settings,
-          semver_matching_lt, semver_matching_lte, semver_matching_gt,
-          valid_version, top_override, {group, git}, {group, pkg},
+          top_override, {group, git}, {group, pkg},
           deps_cmd_needs_update_called
          ].
 
@@ -37,12 +36,6 @@ end_per_group(_, Config) ->
 
 init_per_testcase(valid_version, Config) ->
     rebar_test_utils:init_rebar_state(Config);
-init_per_testcase(semver_matching_lt, Config) ->
-    rebar_test_utils:init_rebar_state(Config);
-init_per_testcase(semver_matching_lte, Config) ->
-    rebar_test_utils:init_rebar_state(Config);
-init_per_testcase(semver_matching_gt, Config) ->
-    rebar_test_utils:init_rebar_state(Config);
 init_per_testcase(newly_added_after_empty_lock, Config) ->
     rebar_test_utils:init_rebar_state(Config);
 init_per_testcase(no_deps_empty_lock, Config) ->
@@ -443,68 +436,6 @@ https_os_proxy_settings(_Config) ->
     ?assertEqual({ok,{{"localhost", 1234}, []}},
                  httpc:get_option(https_proxy, rebar)).
 
-semver_matching_lt(_Config) ->
-    MaxVsn = <<"0.2.0">>,
-    Vsns = [<<"0.1.7">>, <<"0.1.9">>, <<"0.1.8">>, <<"0.2.0">>, <<"0.2.1">>],
-    ?assertEqual({ok, <<"0.1.9">>},
-                 rebar_packages:cmpl_(undefined, MaxVsn, Vsns,
-                                        fun ec_semver:lt/2)).
-
-semver_matching_lte(_Config) ->
-    MaxVsn = <<"0.2.0">>,
-    Vsns = [<<"0.1.7">>, <<"0.1.9">>, <<"0.1.8">>, <<"0.2.0">>, <<"0.2.1">>],
-    ?assertEqual({ok, <<"0.2.0">>},
-                 rebar_packages:cmpl_(undefined, MaxVsn, Vsns,
-                                        fun ec_semver:lte/2)).
-
-semver_matching_gt(_Config) ->
-    MaxVsn = <<"0.2.0">>,
-    Vsns = [<<"0.1.7">>, <<"0.1.9">>, <<"0.1.8">>, <<"0.2.0">>, <<"0.2.1">>],
-    ?assertEqual({ok, <<"0.2.1">>},
-                 rebar_packages:cmp_(undefined, MaxVsn, Vsns,
-                                       fun ec_semver:gt/2)).
-semver_matching_gte(_Config) ->
-    MaxVsn = <<"0.2.0">>,
-    Vsns = [<<"0.1.7">>, <<"0.1.9">>, <<"0.1.8">>, <<"0.2.0">>],
-    ?assertEqual({ok, <<"0.2.0">>},
-                 rebar_packages:cmp_(undefined, MaxVsn, Vsns,
-                                       fun ec_semver:gt/2)).
-
-valid_version(_Config) ->
-    ?assert(rebar_packages:valid_vsn(<<"0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<"0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<" 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"< 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<">0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<">0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"> 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<">  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<=0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<=0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<= 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"<=  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<">=0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<">=0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<">= 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<">=  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"==0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<"==0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"== 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"==  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~>0.1">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~>0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~> 0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~>  0.1.0">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~> 0.1 or 0.5">>)),
-    ?assert(rebar_packages:valid_vsn(<<"~> 0.1-or-something">>)),
-    ?assertNot(rebar_packages:valid_vsn(<<"> 0.1.0 and < 0.2.0">>)),
-    ok.
-
-
 run(Config) ->
     {ok, RebarConfig} = file:consult(?config(rebarconfig, Config)),
     rebar_test_utils:run_and_check(
