@@ -492,16 +492,18 @@ setup_deps_and_repos(Deps, Repos) ->
 
 insert_deps(Deps) ->
     lists:foreach(fun({Name, Version, Repo, Retired}) ->
+                          {ok, Parsed} = rebar_semver:parse_version(Version),
                           ets:insert(?PACKAGE_TABLE, #package{key={rebar_utils:to_binary(Name),
-                                                                   ec_semver:parse(Version),
+                                                                   Parsed,
                                                                    rebar_utils:to_binary(Repo)},
                                                               dependencies=[],
                                                               retired=Retired,
                                                               inner_checksum = <<"inner checksum">>,
                                                               outer_checksum = <<"outer checksum">>});
                      ({Name, Version, InnerChecksum, OuterChecksum, Repo, Retired}) ->
+                         {ok, Parsed} = rebar_semver:parse_version(Version),
                           ets:insert(?PACKAGE_TABLE, #package{key={rebar_utils:to_binary(Name),
-                                                                   ec_semver:parse(Version),
+                                                                   Parsed,
                                                                    rebar_utils:to_binary(Repo)},
                                                               dependencies=[],
                                                               retired=Retired,
